@@ -16,7 +16,8 @@ while 1:
 	4、使用pip中科大
 	5、使用pip豆瓣源
 	6、更新pip版本
-	7、退出
+	7、临时换清华源
+	8、退出
 	'''
 	))
 	cmd_list = ["pip","config","set","global.index-url",]
@@ -45,7 +46,13 @@ while 1:
 		subprocess.Popen("python3 -m pip install --upgrade pip")
 		quit()
 	if choice == 7:
+		disanfangbao = input("请输入安装第三方模块名称，例如：tkinter\n")
+		subprocess.Popen("pip3 install {} -i https://pypi.tuna.tsinghua.edu.cn/simple/".format(disanfangbao))
+		quit()
+
+	if choice == 8:
 		quit()		
 
 # TODO ubuntu换源 
 # TODO deepin换源 
+# TODO 临时换源
\ No newline at end of file
